@@ -1,9 +1,10 @@
-from typing import Callable, Dict, List, Optional
+from typing import Callable, Dict, List, Optional, Literal, Union
 from arcanna_mcp_server.environment import MANAGEMENT_API_KEY
 from arcanna_mcp_server.constants import INTEGRATION_PARAMETERS_SCHEMA_URL, RESOURCES_CRUD_URL
 from arcanna_mcp_server.models.base_resource import BaseResource
 from arcanna_mcp_server.models.resource_type import ResourceType
 from arcanna_mcp_server.utils.exceptions_handler import handle_exceptions
+from arcanna_mcp_server.utils.tool_scopes import requires_scope
 import requests
 
 
@@ -17,6 +18,7 @@ def export_tools() -> List[Callable]:
 
 
 @handle_exceptions
+@requires_scope('read:resources')
 async def integration_parameters_schema(integration_type: Optional[str] = None, role: Optional[str] = None) -> Dict:
     """
         Returns the parameters definition for all integrations (or a selected one) as a JSON schema.
@@ -48,6 +50,7 @@ async def integration_parameters_schema(integration_type: Optional[str] = None,
 
 
 @handle_exceptions
+@requires_scope('write:resources')
 async def upsert_resources(resources: Dict[str, BaseResource], overwrite: Optional[bool] = False) -> Dict:
     """
         Execute a request that creates or updates a set of resources. 
@@ -63,7 +66,16 @@ async def upsert_resources(resources: Dict[str, BaseResource], overwrite: Option
 
         Request is handled in a generic way as parameters for each type of available resource can differ.
 
-        The end goal is to be able to create or update a job.
+        The end goal is to be able to create or update a job (alias for use case).
+
+        When updating the job, always call get_resources() by title to make sure you are not overwriting by mistake parameters that 
+        are already found in the job. Parameters present in the job shouldn't be changed if the user doesn't explicity requests for it.
+        When attempting to update an existing job always confirm with the user before calling upsert_resources().
+
+        job.properties.pipeline_integrations.parameters can be discovered by calling integration_parameters_schema() based on
+        integration_type. They are dynamic for each integration, and they change by the role they have in the pipeline.
+        Role of an integration in the job's pipeline_integrations is specified by the parameter
+        job.properties.pipeline_integrations.integration_type.
 
         --------------------------
 
@@ -119,6 +131,7 @@ async def upsert_resources(resources: Dict[str, BaseResource], overwrite: Option
         '<integration_type>': Available values for integration types and their available parameters
         can be retrieved by calling integration_parameters_schema(). Response is returned as a JSON schema. 
         'integration_type' can be any of the keys from integration_parameters_schema() response on the properties path.
+        Examples can be: 'Elasticsearch', 'External REST API', 'QRadar', 'VirusTotal', etc.
 
         'parameters': <param_key_1>, <param_value_1> keys and values are dynamic for each type of integration.
         They are described  in the response from  integration_parameters_schema() on the path
@@ -209,7 +222,7 @@ async def upsert_resources(resources: Dict[str, BaseResource], overwrite: Option
             - the title of integration as it was saved in arcanna on a previous resource create/update.
             - a query expression where we reference an existing resource eiter by title or by internal id. E.g.:
             "{{integrations(title='Elastic integration')}}", {{integrations(internal_id=1001)}}
-        
+
         '<integration_role>' - Represents the role the integration has in the job. The roles
         in this case can be: 'input', 'processor', 'output', 'enrichment', 'case_creation', 'post_decision'. An integration
         can have multiple roles. For example an Elasticsearch integration can be used both as input and as output.
@@ -234,85 +247,89 @@ async def upsert_resources(resources: Dict[str, BaseResource], overwrite: Option
         Examples:
 
         1). Decision intelligence job with an External REST API input and an Elasticsearch output.
-        
-        Request: 
+
+        Request:
         {
-            "Api Key": {
-                "properties": {
-                    "name": "Api Key from REST API"
+           "resources":
+            {
+                "Api Key": {
+                    "properties": {
+                        "name": "Api Key from REST API"
+                    },
+                    "type": "api_key"
                 },
-                "type": "api_key"
-            },
-            "Elasticsearch from REST API": {
-                "properties": {
-                    "title": "Elasticsearch from REST API",
-                    "integration_type": "Elasticsearch",
-                    "parameters": {
-                        "hosts": "192.168.175.175",
-                        "password": "elastic",
-                        "port": 9200,
-                        "schema": "https",
-                        "user": "elastic"
-                    }
+                "Elasticsearch from REST API": {
+                    "properties": {
+                        "title": "Elasticsearch from REST API",
+                        "integration_type": "Elasticsearch",
+                        "parameters": {
+                            "hosts": "192.168.175.175",
+                            "password": "elastic",
+                            "port": 9200,
+                            "schema": "https",
+                            "user": "elastic"
+                        }
+                    },
+                    "type": "integration"
                 },
-                "type": "integration"
-            },
-            "Exposer integration from REST API": {
-                "properties": {
-                    "title": "Exposer integration from REST API",
-                    "integration_type": "External REST API",
-                    "parameters": {
-                        "api_key": "{{api_keys(name='Api Key from REST API')}}",
-                        "data_type": "JSON alerts"
-                    }
+                "Exposer integration from REST API": {
+                    "properties": {
+                        "title": "Exposer integration from REST API",
+                        "integration_type": "External REST API",
+                        "parameters": {
+                            "api_key": "{{api_keys(name='Api Key from REST API')}}",
+                            "data_type": "JSON alerts"
+                        }
+                    },
+                    "type": "integration"
                 },
-                "type": "integration"
-            },
-            "Exposer input job from REST API": {
-                "properties": {
-                    "title": "Exposer input job from REST API",
-                    "description": "This is a sample job",
-                    "category": "Decision intelligence",
-                    "decision_points": [
-                        "event.outcome",
-                        "event.category"
-                    ],
-                    "advanced_settings": {
-                        "custom_labels": [
+                "Exposer input job from REST API": {
+                    "properties": {
+                        "title": "Exposer input job from REST API",
+                        "description": "This is a sample job",
+                        "category": "Decision intelligence",
+                        "decision_points": [
+                            "event.outcome",
+                            "event.category"
+                        ],
+                        "advanced_settings": {
+                            "custom_labels": [
+                                {
+                                    "name": "Important",
+                                    "hex_color": "#a83232"
+                                },
+                                {
+                                    "name": "Discard",
+                                    "hex_color": "#030bff"
+                                },
+                                {
+                                    "name": "Potential risk",
+                                    "hex_color": "#ffcd03"
+                                }
+                            ]
+                        },
+                        "pipeline_integrations": [
                             {
-                                "name": "Important",
-                                "hex_color": "#a83232"
+                                "resource": "Exposer integration from REST API",
+                                "integration_type": "input",
+                                "enabled": true,
+                                "parameters": {
+                                    "exposed_rest_api_job_tag": "rest_api_exposer",
+                                    "max_batch_size": 100
+                                }
                             },
                             {
-                                "name": "Discard",
-                                "hex_color": "#030bff"
-                            },
-                            {
-                                "name": "Potential risk",
-                                "hex_color": "#ffcd03"
+                                "resource": "Elasticsearch from REST API",
+                                "integration_type": "output",
+                                "enabled": true,
+                                "parameters": {}
                             }
                         ]
                     },
-                    "pipeline_integrations": [
-                        {
-                            "resource": "Exposer integration from REST API",
-                            "integration_type": "input",
-                            "enabled": true,
-                            "parameters": {
-                                "exposed_rest_api_job_tag": "rest_api_exposer",
-                                "max_batch_size": 100
-                            }
-                        },
-                        {
-                            "resource": "Elasticsearch from REST API",
-                            "integration_type": "output",
-                            "enabled": true,
-                            "parameters": {}
-                        }
-                    ]
-                },
-                "type": "job"
+                    "type": "job"
+                }
             }
+            "overwrite": true
         }
 
         Response:
@@ -379,8 +396,9 @@ async def upsert_resources(resources: Dict[str, BaseResource], overwrite: Option
     return response_json
 
 
+@requires_scope('read:resources')
 async def get_resources(
-        resource_type: Optional[ResourceType] = None, title: Optional[str] = None, id: Optional[str] = None) -> Dict:
+        resource_type: Optional[Literal[ResourceType.API_KEY, ResourceType.INTEGRATION, ResourceType.JOB]] = None, title: Optional[str] = None, id: Optional[Union[str, int]] = None) -> Dict:
     """
         Returns a list of resources. Parameters behave as filters.
         If no parameter is provided all available resources from arcanna are returned. Information about jobs/use cases
@@ -410,14 +428,15 @@ async def get_resources(
     if title:
         params["title"] = title
     elif id:
-        params["id"] = id
+        params["id"] = str(id)
 
     response = requests.get(RESOURCES_CRUD_URL, headers=headers, params=params)
     return response.json()
 
 
+@requires_scope('delete:resources')
 async def delete_resources(
-        resource_type: ResourceType, title: Optional[str] = None, id: Optional[str] = None) -> Dict:
+        resource_type: Literal[ResourceType.API_KEY, ResourceType.INTEGRATION, ResourceType.JOB], title: Optional[str] = None, id: Optional[Union[str, int]] = None) -> Dict:
     """
         Returns a list of resources. Parameters behave as filters.
         If no parameter is provided all available resources from arcanna are returned.
@@ -444,7 +463,7 @@ async def delete_resources(
     if title:
         params["title"] = title
     elif id:
-        params["id"] = id
+        params["id"] = str(id)
 
     response = requests.delete(RESOURCES_CRUD_URL, headers=headers, params=params)
     return response.json()
