@@ -1,15 +1,17 @@
 from datetime import datetime
 from typing import Callable, List
 from arcanna_mcp_server.utils.exceptions_handler import handle_exceptions
+from arcanna_mcp_server.utils.tool_scopes import requires_scope
 
 
 def export_tools() -> List[Callable]:
     return [
-        get_system_timestamp,
+        get_system_timestamp
     ]
 
 
 @handle_exceptions
+@requires_scope('public')
 async def get_system_timestamp() -> str:
     """
         Get current system timestamp.
